package game_room;

public class TicTacToe {
	private static final int MAX_MOVES = 9;
	private static final char P1_MARKER = 'X';
	private static final char P2_MARKER = 'O';
	
	private Player p1, p2, winner;
	private int numMoves;
	private char[][] board;
	
	public TicTacToe(Player p1, Player p2) {
		this.p1 = p1;
		this.p2 = p2;
		winner = null;
		numMoves = 0;
		
		// Initialize board with empty cells
		board = new char[3][3];
		for (int i = 0; i < board.length; i++) {
			for (int j = 0; j < board[i].length; j++) {
				board[i][j] = ' ';
			}
		}
	}
	
	public void playNextMove() {
		// Any nontrivial implementation would ask the next player where to play.
		// This implementation just fills up the cells row by row, column by
		// column, in order.
		Player nextPlayer = (numMoves % 2 == 0) ? p1 : p2; 
		int row = numMoves / board.length;
		int col = numMoves % board[0].length;
		board[row][col] = (nextPlayer == p1) ? P1_MARKER : P2_MARKER;
		numMoves++;
		
		// Is the game over? Always play the game until the whole board is filled,
		// then arbitrarily declare p1 the winner. (These are the rules of
		// Tic Tac Toe as implemented at 5:30am.)
		if (numMoves == MAX_MOVES) {
			winner = p1;
		}
		
		System.out.println("Played move #" + numMoves);
		printBoard();
		System.out.println();
	}
	
	public boolean isComplete() {
		return (winner != null || numMoves == MAX_MOVES);
	}
	
	public boolean isDraw() {
		return (isComplete() && winner == null);
	}
	
	public Player getWinner() {
		return winner;
	}
	
	private void printBoard() {
		for (int i = 0; i < board.length; i++) {
			for (int j = 0; j < board[i].length; j++) {
				System.out.print(board[i][j] + " ");
			}
			System.out.println();
		}
	}
	
	@Override
	public String toString() {
		return "Tic-Tac-Toe";
	}
}
