package game_room.rock_paper_scissors;

import game_room.Game;
import game_room.Player;

import java.util.Scanner;


public class RockPaperScissors implements Game {
	private static final int TOTAL_ROUNDS = 3;

	// Number of rounds played so far and number of rounds P1 won
	private Scanner console;
	private Player humanPlayer, computerPlayer, winner;
	private RPSStrategy computerStrategy;
	
	public RockPaperScissors(Player humanPlayer) {
		console = new Scanner(System.in);
		this.humanPlayer = humanPlayer;
		this.computerPlayer = new Player();
		this.computerStrategy = new RockStrategy();
		this.winner = null;
	}
	
	// Play at least three rounds, or as many as needed to break a tie
	public void play() {
		winner = null;
		int humanWins = 0;
		int computerWins = 0;
		int roundsPlayed = 0;
		
		while (roundsPlayed < TOTAL_ROUNDS || humanWins == computerWins) {
			Weapon humanWeapon = getPersonWeapon();
			Weapon computerWeapon = computerStrategy.chooseWeapon();
			if (humanWeapon.defeats(computerWeapon)) {
				printWinningRound(humanPlayer, humanWeapon, computerWeapon);
				humanWins++;
			} else if (computerWeapon.defeats(computerWeapon)) {
				System.out.println(computerWeapon + " beats " + humanWeapon);
				computerWins++;
			} else {
				System.out.println("It's a tie!");
			}
			
			roundsPlayed++;
		}
		
		winner = (humanWins > computerWins) ? humanPlayer : computerPlayer;
		winner.addWin();
	}
	
	private void printWinningRound(Player winner, Weapon winningWeapon, Weapon losingWeapon) {
		System.out.println(winningWeapon + " beats " + losingWeapon + "; " + winner + " wins!");
	}
	
	public Weapon getPersonWeapon() {
		while (true) {
			System.out.print("Enter r for rock, p for paper, or s for scissors: ");
			String choice = console.nextLine();
			if (choice.equals("r")) {
				return Weapon.ROCK;
			} else if (choice.equals("p")) {
				return Weapon.PAPER;
			} else if (choice.equals("s")) {
				return Weapon.SCISSORS;
			}
		}
	}
	
	public Player getWinner() {
		return winner;
	}
	
	@Override
	public String toString() {
		return "Rock, Paper, Scissors";
	}
}
