package patterns_singleton;

import java.io.File;

/**
 * Stores state and manages interaction for a single connection betweem the
 * file server and some client.
 * Looks up files by name and would theoretically send their contents to
 * the user. In our our fake client implementation, we don't actually
 * do anything with the file at all. How silly.
 * 
 * @author Krysta
 *
 */
public class Client {
	private Logger logger;
	
	public Client() {
		logger = Logger.getInstance(); 
	}
	
	/**
	 * Asks the user for the filename and reads the next file
	 */
	public void readNextFile() {
		String fname = IOUtil.getFilename();
		File f = new File(fname);
		if (f.exists()) {
			// Here we would open the file, read it, and send the contents
			// back to the client
			logger.write("Read file: " + fname);
		} else {
			logger.write("ERROR: File not found: " + fname);
		}
	}
}
